
Hydrophobicity Scales
=====================

Wimley-White
------------
``wimley_white.csv`` contains the scale from [1]. The represents the 

[1] 
Octanol-water hydrophobicity scale from White (1996) Biochem 35  
Amino acids are assumed charged  
Suffix 0 denotes uncharged version

